@@ -32,7 +32,7 @@ class Plan:
         return self._dag
 
     @property
-    def leaves(self) -> t.Generator[Step, None, None]:
+    def leaves(self) -> t.Iterator[Step]:
         return (node for node, deps in self.dag.items() if not deps)
 
     def __repr__(self) -> str:
@@ -175,7 +175,7 @@ class Step:
             }
             for projection in projections:
                 for i, e in aggregate.group.items():
-                    for child, _, _ in projection.walk():
+                    for child, *_ in projection.walk():
                         if child == e:
                             child.replace(exp.column(i, step.name))
             aggregate.add_dependency(step)
@@ -192,6 +192,17 @@ class Step:
 
         step.projections = projections
 
+        if isinstance(expression, exp.Select) and expression.args.get("distinct"):
+            distinct = Aggregate()
+            distinct.source = step.name
+            distinct.name = step.name
+            distinct.group = {
+                e.alias_or_name: exp.column(col=e.alias_or_name, table=step.name)
+                for e in projections or expression.expressions
+            }
+            distinct.add_dependency(step)
+            step = distinct
+
         limit = expression.args.get("limit")
 
         if limit:
@@ -235,6 +246,9 @@ class Step:
         if self.condition:
             lines.append(f"{nested}Condition: {self.condition.sql()}")
 
+        if self.limit is not math.inf:
+            lines.append(f"{nested}Limit: {self.limit}")
+
         if self.dependencies:
             lines.append(f"{nested}Dependencies:")
             for dependency in self.dependencies:
@@ -387,7 +401,7 @@ class SetOperation(Step):
             op=expression.__class__,
             left=left.name,
             right=right.name,
-            distinct=expression.args.get("distinct"),
+            distinct=bool(expression.args.get("distinct")),
         )
         step.add_dependency(left)
         step.add_dependency(right)
